@@ -37,7 +37,7 @@ class Guild:
         self.members = GuildMembers(self.api, data.get("guild", {}).get("members"))
         self.created = datetime.datetime.fromtimestamp(data.get("guild", {}).get("created", 0) / 1000)
         self.level = Level(data.get("guild", {}).get("exp"))
-        self.experience = self.xp = self.exp = Level(data.get("guild", {}).get("exp"))
+        self.experience = self.xp = self.exp = Level(data.get("guild", {}).get("exp", 0))
 
     def __str__(self):
         return self.name
